=======
Changes
=======

0.1.1 / 2018-07-21
==================

* Fix support to python 3.4 and 3.5 versions

0.1.0 / 2018-03-24
==================

* Implement ``redistore.get()`` function
* Add RedisStore with special methods such as __getitem__, __delitem__ etc.
* Add redistore support to hashes
* Add redistore support to strings
